<div id="quarto-content" class="page-columns page-rows-contents page-layout-<%- pageLayout %><%- tocLocation === "left" ? " toc-left" : ""%>">

<% if (tocLocation === "left") { %>
<div id="quarto-sidebar-toc-left" class="sidebar toc-left">
  <div id="quarto-toc-target"></div>
</div>
<% } %>

<div id="quarto-margin-sidebar" class="sidebar margin-sidebar">
  <% if (tocLocation === "right") { %>
  <div id="quarto-toc-target"></div>
  <% } %>
</div>

<main class="content" id="quarto-document-content">
