[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula A"}},"key":"1D4D0"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula B"}},"key":"1D4D1"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula C"}},"key":"1D4D2"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula D"}},"key":"1D4D3"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula E"}},"key":"1D4D4"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula F"}},"key":"1D4D5"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula G"}},"key":"1D4D6"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula H"}},"key":"1D4D7"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula I"}},"key":"1D4D8"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula J"}},"key":"1D4D9"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula K"}},"key":"1D4DA"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula L"}},"key":"1D4DB"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula M"}},"key":"1D4DC"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula N"}},"key":"1D4DD"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula O"}},"key":"1D4DE"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula P"}},"key":"1D4DF"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula Q"}},"key":"1D4E0"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula R"}},"key":"1D4E1"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula S"}},"key":"1D4E2"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula T"}},"key":"1D4E3"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula U"}},"key":"1D4E4"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula V"}},"key":"1D4E5"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula W"}},"key":"1D4E6"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula X"}},"key":"1D4E7"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula Y"}},"key":"1D4E8"},{"category":"Lu","mappings":{"default":{"default":"negrita script mayúscula Z"}},"key":"1D4E9"},{"category":"Ll","mappings":{"default":{"default":"negrita script a"}},"key":"1D4EA"},{"category":"Ll","mappings":{"default":{"default":"negrita script b"}},"key":"1D4EB"},{"category":"Ll","mappings":{"default":{"default":"negrita script c"}},"key":"1D4EC"},{"category":"Ll","mappings":{"default":{"default":"negrita script d"}},"key":"1D4ED"},{"category":"Ll","mappings":{"default":{"default":"negrita script e"}},"key":"1D4EE"},{"category":"Ll","mappings":{"default":{"default":"negrita script f"}},"key":"1D4EF"},{"category":"Ll","mappings":{"default":{"default":"negrita script g"}},"key":"1D4F0"},{"category":"Ll","mappings":{"default":{"default":"negrita script h"}},"key":"1D4F1"},{"category":"Ll","mappings":{"default":{"default":"negrita script i"}},"key":"1D4F2"},{"category":"Ll","mappings":{"default":{"default":"negrita script j"}},"key":"1D4F3"},{"category":"Ll","mappings":{"default":{"default":"negrita script k"}},"key":"1D4F4"},{"category":"Ll","mappings":{"default":{"default":"negrita script l"}},"key":"1D4F5"},{"category":"Ll","mappings":{"default":{"default":"negrita script m"}},"key":"1D4F6"},{"category":"Ll","mappings":{"default":{"default":"negrita script n"}},"key":"1D4F7"},{"category":"Ll","mappings":{"default":{"default":"negrita script o"}},"key":"1D4F8"},{"category":"Ll","mappings":{"default":{"default":"negrita script p"}},"key":"1D4F9"},{"category":"Ll","mappings":{"default":{"default":"negrita script q"}},"key":"1D4FA"},{"category":"Ll","mappings":{"default":{"default":"negrita script r"}},"key":"1D4FB"},{"category":"Ll","mappings":{"default":{"default":"negrita script s"}},"key":"1D4FC"},{"category":"Ll","mappings":{"default":{"default":"negrita script t"}},"key":"1D4FD"},{"category":"Ll","mappings":{"default":{"default":"negrita script u"}},"key":"1D4FE"},{"category":"Ll","mappings":{"default":{"default":"negrita script v"}},"key":"1D4FF"},{"category":"Ll","mappings":{"default":{"default":"negrita script w"}},"key":"1D500"},{"category":"Ll","mappings":{"default":{"default":"negrita script x"}},"key":"1D501"},{"category":"Ll","mappings":{"default":{"default":"negrita script y"}},"key":"1D502"},{"category":"Ll","mappings":{"default":{"default":"negrita script z"}},"key":"1D503"}]
